==> camel-blueprint-2.17-20160313.045626-29-sources.jar: org/apache/camel/blueprint/CamelRestContextFactoryBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.blueprint;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.model.IdentifiedType;
import org.apache.camel.model.rest.RestDefinition;

@XmlRootElement(name = "restContext")
@XmlAccessorType(XmlAccessType.FIELD)
public class CamelRestContextFactoryBean extends IdentifiedType {

    @XmlElement(name = "rest", required = true)
    private List<RestDefinition> rests = new ArrayList<RestDefinition>();

    public List<RestDefinition> getRests() throws Exception {
        return rests;
    }

}

==> camel-blueprint-2.24.2-sources.jar: org/apache/camel/blueprint/CamelRestContextFactoryBean.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.blueprint;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.model.IdentifiedType;
import org.apache.camel.model.rest.RestDefinition;

@XmlRootElement(name = "restContext")
@XmlAccessorType(XmlAccessType.FIELD)
public class CamelRestContextFactoryBean extends IdentifiedType {

    @XmlElement(name = "rest", required = true)
    private List<RestDefinition> rests = new ArrayList<>();

    public List<RestDefinition> getRests() throws Exception {
        return rests;
    }

}
